@@ -3,6 +3,6 @@ from trdb2py.config import loadConfig
 from trdb2py.trdb2 import simTradings, getAssetCandles, simTrading
 from trdb2py.utils import str2Asset, nextWeekDay, asset2Str
 from trdb2py.pdutils import buildPNLReport
-from trdb2py.statistics import calcPNLWinRateInYear, buildPNLWinRateInYears
-from trdb2py.plotly import showAssetCandles, showHeatmap, showHeatmapWinRateInYears
+from trdb2py.statistics import calcPNLWinRateInYear, buildPNLWinRateInYears, buildPNLWinRateInMonths, buildPNLListWinRateInYears2
+from trdb2py.plotly import showAssetCandles, showHeatmap, showHeatmapWinRateInYears, showWinRateInYears
 import trdb2py.trading2_pb2
