@@ -4,7 +4,7 @@ import time
 import plotly.express as px
 from plotly.subplots import make_subplots
 import plotly.graph_objects as go
-from trdb2py.statistics import buildPNLWinRateInYears
+from trdb2py.statistics import buildPNLWinRateInYears, buildPNLListWinRateInYears2
 
 
 def showAssetCandles(title: str, dfCandles: pd.DataFrame, columm: str = 'close', toImg: bool = False):
@@ -57,3 +57,19 @@ def showHeatmapWinRateInYears(lstpnl: list, sortby: str = '', valtype: str = '',
     # print(columns)
 
     showHeatmap(df, columns, valtype, valoff, toImg)
+
+
+def showWinRateInYears(lstpnl: list, valtype: str = '', valoff: float = 0.0, toImg: bool = False):
+    arr = buildPNLListWinRateInYears2(lstpnl)
+
+    fig = go.Figure()
+
+    for v in arr:
+        fig.add_trace(go.Scatter(x=v['df']['date'], y=v['df']['winrate'],
+                                 mode='lines',
+                                 name=v['title']))
+
+    if toImg:
+        fig.show(renderer="png")
+    else:
+        fig.show()
